pydeflate.get\_data package
===========================

Submodules
----------

pydeflate.get\_data.imf\_data module
------------------------------------

.. automodule:: pydeflate.get_data.imf_data
   :members:
   :undoc-members:
   :show-inheritance:

pydeflate.get\_data.oecd\_data module
-------------------------------------

.. automodule:: pydeflate.get_data.oecd_data
   :members:
   :undoc-members:
   :show-inheritance:

pydeflate.get\_data.wb\_data module
-----------------------------------

.. automodule:: pydeflate.get_data.wb_data
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pydeflate.get_data
   :members:
   :undoc-members:
   :show-inheritance:
